pub struct WebLifecycle { /* private fields */ }Expand description
Browser page and network lifecycle listeners for a managed socket.
Keep this value alive while the socket is active. Dropping it removes all installed event listeners.
Implementations